@@ -6,10 +6,11 @@
 #' @return void
 #' @rdname assert
 #' @keywords internal
-#' @importFrom checkmate checkClass checkNumeric assert
-assert_unit <- function(var, allow_missing = TRUE){
-  if (missing(var) && allow_missing)
+#' @importFrom checkmate assert checkClass checkNumeric
+assert_unit <- function(var, allow_missing = TRUE) {
+  if (missing(var) && allow_missing) {
     return()
+  }
 
   assert(
     checkClass(var, "unit"),
@@ -26,10 +27,11 @@ assert_unit <- function(var, allow_missing = TRUE){
 #' @return void
 #' @rdname assert
 #' @keywords internal
-#' @importFrom checkmate checkString checkNumeric assert
-assert_label <- function(var, allow_missing = TRUE){
-  if (missing(var) && allow_missing)
+#' @importFrom checkmate assert checkString checkNumeric
+assert_label <- function(var, allow_missing = TRUE) {
+  if (missing(var) && allow_missing) {
     return()
+  }
 
   assert(
     checkString(var),
@@ -40,20 +42,21 @@ assert_label <- function(var, allow_missing = TRUE){
 
 #' Assert valid color
 #'
-#' @param var Varible 2 check
+#' @param var Variable 2 check
 #' @param allow_missing Allow missing variables
 #'
 #' @return void
 #' @rdname assert
 #' @keywords internal
-#' @importFrom checkmate checkString assert
-assert_just <- function(var, allow_missing = TRUE){
-  if (missing(var) && allow_missing)
+#' @importFrom checkmate assert checkCharacter checkNumeric
+assert_just <- function(var, allow_missing = TRUE) {
+  if (missing(var) && allow_missing) {
     return()
+  }
 
   assert(
-    checkString(var, pattern = "left|right|top|bottom|center"),
-    checkNumeric(var, lower = 0, upper = 1),
+    checkCharacter(var, pattern = "^left|right|top|bottom|center|centre$", max.len = 2),
+    checkNumeric(var, lower = 0, upper = 1, max.len = 2),
     .var.name = dep_var(var)
   )
 }
@@ -62,6 +65,6 @@ dep_var <- function(x) {
   nn <- substitute(x)
   on <- do.call("substitute", list(as.name(nn), parent.frame(1)))
   paste0(deparse(deparse(on), width.cutoff = 500),
-         collapse = "\n")
-}
-
+    collapse = "\n"
+  )
+}
\ No newline at end of file
